ChatBotTheme class

Constructors

ChatBotTheme({Color? backgroundColor, Color? userMessageColor, Color? botMessageColor, Color? userMessageTextColor, Color? botMessageTextColor, Color? sendButtonColor, Color? textFieldBorderColor, Color? predefinedButtonColor, Color? predefinedButtonTextColor, TextStyle? titleTextStyle, TextStyle? messageTextStyle, InputDecoration? textFieldDecoration, IconData? sendIcon, BoxDecoration? predefinedButtonDecoration, TextStyle? predefinedButtonTextStyle, Color? predefinedButtonBorderColor, double? predefinedButtonBorderRadius, EdgeInsetsGeometry? predefinedButtonPadding, Color? predefinedContainerBorderColor, Color? pageAppBarBgColor, TextStyle? pageAppBarTextStyle})
const
ChatBotTheme.defaultTheme(Color primary)
factory

Properties

backgroundColor Color?
final
botMessageColor Color?
final
botMessageTextColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
messageTextStyle TextStyle?
final
pageAppBarBgColor Color?
final
pageAppBarTextStyle TextStyle?
final
predefinedButtonBorderColor Color?
final
predefinedButtonBorderRadius double?
final
predefinedButtonColor Color?
final
predefinedButtonDecoration BoxDecoration?
final
predefinedButtonPadding EdgeInsetsGeometry?
final
predefinedButtonTextColor Color?
final
predefinedButtonTextStyle TextStyle?
final
predefinedContainerBorderColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendButtonColor Color?
final
sendIcon IconData?
final
textFieldBorderColor Color?
final
textFieldDecoration InputDecoration?
final
titleTextStyle TextStyle?
final
userMessageColor Color?
final
userMessageTextColor Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited